/**
 *  \file nothing.cpp
 *  \brief nothing
 *
 *  Copyright 2007-2013 IMP Inventors. All rights reserved.
 *
 */

#include <debug/vector>
int main(void) { return 0; }
